@@ -2,7 +2,7 @@ import client
 import common
 
 import pandas as pd
-import functools, pickle, operator
+import functools, dill, pickle, operator
 
 def fetch_results(jobs: list, conn):
   job_ids = f"{jobs}"[1:-1]
